import 'package:flutter/material.dart';
import 'package:go_router/go_router.dart';
import 'package:hooks_riverpod/hooks_riverpod.dart';
import 'package:moneymgr_mobile/services/router/routes_list.dart';
import 'package:moneymgr_mobile/services/storage/expenses.dart';
import 'package:moneymgr_mobile/utils/time_utils.dart';
import 'package:riverpod_annotation/riverpod_annotation.dart';

part 'scans_list_screen.g.dart';

@riverpod
Future<ExpensesList> _expensesList(Ref ref) {
  final expenses = ref.watch(expensesProvider).requireValue;
  return expenses.getList();
}

class ScansListScreen extends HookConsumerWidget {
  const ScansListScreen({super.key});

  @override
  Widget build(BuildContext context, WidgetRef ref) {
    final expensesList = ref.watch(_expensesListProvider);
    return Scaffold(
      appBar: AppBar(title: Text("Expenses")),
      body: switch (expensesList) {
        AsyncData(:final value) => _ExpensesList(list: value),
        AsyncError(:final error) => Center(child: Text('Load error: $error')),
        _ => const Center(child: CircularProgressIndicator()),
      },
    );
  }
}

class _ExpensesList extends StatelessWidget {
  final ExpensesList list;

  const _ExpensesList({required this.list});

  @override
  Widget build(BuildContext context) {
    return ListView.builder(
      itemBuilder: (context, entryNum) {
        final expense = list[entryNum];
        return ListTile(
          onTap: () => context.push("$scansPage/${expense.id}"),
          leading: Icon(Icons.receipt_long),
          title: Text(
            expense.label ?? "No label",
            style: TextStyle(
              fontStyle: expense.label == null ? FontStyle.italic : null,
            ),
          ),
          subtitle: Text(expense.dateTime.simpleDate),
          trailing: Text("${expense.cost} €", style: TextStyle(fontSize: 20)),
        );
      },
      itemCount: list.length,
    );
  }
}
